@@ -7,7 +7,8 @@ from lunar_python import Lunar
 def 咦():
     today = datetime.datetime.today()
     lunar = Lunar.fromYmd(today.year, today.month, today.day)
-    return '诸事不宜' not in lunar.getTimeJi()
+    # return '诸事不宜' not in lunar.getTimeJi()
+    return False
 
 
 class _(unittest.TestCase):
